package com.ruoyi.benyun.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.benyun.entity.AttentionPool;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

@Mapper
public interface AttentionPoolDao extends BaseMapper<AttentionPool> {
    int searchCountByUserId(String userId);
    List<AttentionPool> searchByMulti(@Param("text") String text, @Param("userId") String userId);
    int deleteByAttentionIdAndUserId(@Param("attentionId") String attentionId, @Param("userId") String userId);
    AttentionPool searchByAttentionIdAndUserId(@Param("attentionId") String attentionId, @Param("userId") String userId);
    AttentionPool searchByBrandIdOrWdIdAndUserId(@Param("brandId") String brandId, @Param("wdId") String wdId, @Param("userId") String userId);
    int deleteByBrandIdOrWdIdAndUserId(@Param("brandId") String brandId, @Param("wdId") String wdId, @Param("userId") String userId);
    Integer selectCount(@Param("userId") String userId);
    List<String> selectAllUser();
}
